-- JSON Queries
--
-- Example Queries using JSON in Oracle
--
--
set echo on
set linesize 100
set pagesize 1000
set long 8192

-- Simple query from JSON data
select dept_info
  from deptj;
--
-- Query using json_value (returns scalar value)
select json_value(dept_info
     , '$.departments.DNAME')
   from deptj;
--
-- Query using json_value and more-complex path notation
select json_value(dept_info
     , '$.departments.DEPTEMPS[0].ENAME')
   from deptj;
--
-- Query usin json_table (useful for building SQL views)
select ename,job ,sal
   from deptj
       ,json_table(dept_info,'$.departments.DEPTEMPS[*]'
         columns (ename varchar2(20) path '$.ENAME'
                 ,job   varchar2(20) path '$.JOB'
                 ,sal   number       path '$.pay.SAL'
                  ));
--
--
-- Query showing json_exists
select * 
  from deptj
  where json_exists(dept_info,'$.*.DEPTEMPS');
--
-- Query combining json_exists with json_value
select json_value(dept_info
     , '$.departments.DEPTEMPS[1].ENAME')
   from deptj
    where  json_exists(dept_info,'$.*.DEPTEMPS');
--
set echo on
-- Query using json_query
set long 8192
set pagesize 100
select dept_info
   from deptj
   where json_exists(dept_info, '$[0].departments.DEPTNO')
 ;
 select dept_info
   from deptj
   where json_value(dept_info, '$[0].departments.DEPTNO') = '10'
 ;
 select json_value(dept_info, '$[0].departments.DEPTNO')
   from deptj
 ;
 select dept_info
   from deptj
   where json_textcontains(dept_info, '$.departments.DEPTNO', '10')
 ;
-- Query using json_query
set pagesize 100
select json_query(dept_info,'$.departments.DEPTEMPS' )
   from deptj
 ;
-- Query using json_query
select json_query(dept_info,'$.departments' )
   from deptj
 ;
-- More-complex
-- Query using json_table (useful for building SQL views)
select dname,ename,job,sal
   from deptj
       ,json_table(dept_info,'$.departments'
         columns (dname varchar2(15) path '$.DNAME'
                 ,nested path '$.DEPTEMPS[*]'
                    columns (ename varchar2(20) path '$.ENAME'
                            ,job   varchar2(20) path '$.JOB'
                            ,nested path '$.pay'
                              columns (sal number path '$.SAL')
                    )
                  ));
--
drop view deptj_view;
create view deptj_view 
as
select dname,ename,job,sal
   from deptj
       ,json_table(dept_info,'$.departments'
         columns (dname varchar2(15) path '$.DNAME'
                 ,nested path '$.DEPTEMPS[*]'
                    columns (ename varchar2(20) path '$.ENAME'
                            ,job   varchar2(20) path '$.JOB'
                            ,nested path '$.pay'
                              columns (sal number path '$.SAL')
                    )
                  ));
select * from deptj_view
  where job = 'MANAGER';
