-- 12c PL/SQL Deprecation
--
-- Note use of "pragma deprecate" to mark deprecation
create or replace procedure addem
(inval1 in number, inval2 in number, outval in out number)
as
 pragma deprecate (ADDEM, 'ADDEM deprecated, use ADDEM_N17 instead');
begin
  dbms_output.put_line('Original version');
  outval := inval1 + inval2;
end;
/
-- 
-- NEW "undeprecated" procedure
create or replace procedure addem_n17
(inval1 in number, inval2 in number, outval in out number)
as
begin
  dbms_output.put_line('New improved version');
  outval := inval1 + inval2;
end;
/
-- 
-- turn on warnings
alter session set plsql_warnings = 'enable:(6019,6020,6021,6022)';
--
-- does not work on anonymous PL/SQL block
declare
  in1 number := 18;
  in2 number := 24;
  res number := 0;
begin
  addem(in1,in2,res);
  dbms_output.put_line(in1 || ' + ' || in2 || ' = ' || res);
end;
/
--
-- works on other stored PL/SQL upon compile
create or replace procedure addemup (
  value1 in number
  ,value2 in number
  ,outputvalue in out number)
is
  resultvalue number := 0;
begin
  addem(value1, value2, outputvalue);
end;
/
--
-- make deprecation an error
alter session set plsql_warnings = 'error:6020';
-- using old version throws error
create or replace procedure addemup (
   value1 in number
  ,value2 in number
  ,outputvalue in out number)
is
  resultvalue number := 0;
begin
  addem(value1, value2, outputvalue);
end;
/
--
-- using new version avoids error
create or replace procedure addemup (
   value1 in number
  ,value2 in number
  ,outputvalue in out number)
is
  resultvalue number := 0;
begin
  addem_n17(value1, value2, outputvalue);
end;
/
